@@ -5,8 +5,8 @@ from rest_framework.response import Response
 from rest_framework.permissions import IsAuthenticatedOrReadOnly
 from bluedot_rest_framework import import_string
 
-EventConfiguration = import_string('EVENT.configuration.models')
-EventConfigurationSerializer = import_string('EVENT.configuration.serializers')
+EventConfiguration = import_string('event.configuration.models')
+EventConfigurationSerializer = import_string('event.configuration.serializers')
 
 
 class EventConfigurationView(CustomModelViewSet):
