@@ -6,9 +6,9 @@ from django.conf import settings
 class OSS:
     def __init__(self):
         self.auth = oss2.Auth(
-            settings.BLUEDOT_REST_FRAMEWORK['UTILS']['OSS']['access_key_id'], settings.BLUEDOT_REST_FRAMEWORK['UTILS']['OSS']['access_key_secret'])
+            settings.BLUEDOT_REST_FRAMEWORK['utils']['OSS']['access_key_id'], settings.BLUEDOT_REST_FRAMEWORK['utils']['OSS']['access_key_secret'])
         self.bucket = oss2.Bucket(
-            self.auth, settings.BLUEDOT_REST_FRAMEWORK['UTILS']['OSS']['endpoint'], settings.BLUEDOT_REST_FRAMEWORK['UTILS']['OSS']['bucket_name'])
+            self.auth, settings.BLUEDOT_REST_FRAMEWORK['utils']['OSS']['endpoint'], settings.BLUEDOT_REST_FRAMEWORK['utils']['OSS']['bucket_name'])
 
     def put_object_internet(self, url, path):
         try:
